Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS CodeBuild.

Actions, resources, and condition keys for AWS CodeBuild - Service Authorization Reference

# Actions, resources, and condition keys for AWS CodeBuild

AWS CodeBuild (service prefix: `codebuild` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS CodeBuild
- Resource types defined by AWS CodeBuild
- Condition keys for AWS CodeBuild

## Actions defined by AWS CodeBuild

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
BatchDeleteBuilds | Grants permission to delete one or more builds | Write | project* |  |
BatchGetBuildBatches | Grants permission to get information about one or more build batches | Read | project* |  |
BatchGetBuilds | Grants permission to get information about one or more builds | Read | project* |  |
BatchGetProjects | Grants permission to get information about one or more build projects | Read | project* |  |
BatchGetReportGroups | Grants permission to return an array of ReportGroup objects that are specified by the input reportGroupArns parameter | Read | report-group* |  |
BatchGetReports | Grants permission to return an array of the Report objects specified by the input reportArns parameter | Read | report-group* |  |
BatchPutCodeCoverages [permission only] | Grants permission to add or update information about a report | Write | report-group* |  |
BatchPutTestCases [permission only] | Grants permission to add or update information about a report | Write | report-group* |  |
CreateProject | Grants permission to create a build project | Write | project* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateReport [permission only] | Grants permission to create a report. A report is created when tests specified in the buildspec file for a report groups run during the build of a project | Write | report-group* |  |
CreateReportGroup | Grants permission to create a report group | Write | report-group* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateWebhook | Grants permission to create webhook. For an existing AWS CodeBuild build project that has its source code stored in a GitHub or Bitbucket repository, enables AWS CodeBuild to start rebuilding the source code every time a code change is pushed to the repository | Write | project* |  |
DeleteBuildBatch | Grants permission to delete a build batch | Write | project* |  |
DeleteOAuthToken [permission only] | Grants permission to delete an OAuth token from a connected third-party OAuth provider. Only used in the AWS CodeBuild console | Write |  |  |
DeleteProject | Grants permission to delete a build project | Write | project* |  |
DeleteReport | Grants permission to delete a report | Write | report-group* |  |
DeleteReportGroup | Grants permission to delete a report group | Write | report-group* |  |
DeleteResourcePolicy | Grants permission to delete a resource policy for the associated project or report group | Permissions management | project |  |
report-group |  |
DeleteSourceCredentials | Grants permission to delete a set of GitHub, GitHub Enterprise, or Bitbucket source credentials | Write |  |  |
DeleteWebhook | Grants permission to delete webhook. For an existing AWS CodeBuild build project that has its source code stored in a GitHub or Bitbucket repository, stops AWS CodeBuild from rebuilding the source code every time a code change is pushed to the repository | Write | project* |  |
DescribeCodeCoverages | Grants permission to return an array of CodeCoverage objects | Read | report-group* |  |
DescribeTestCases | Grants permission to return an array of TestCase objects | Read | report-group* |  |
GetReportGroupTrend | Grants permission to analyze and accumulate test report values for the test reports in the specified report group | Read | report-group* |  |
GetResourcePolicy | Grants permission to return a resource policy for the specified project or report group | Read | project |  |
report-group |  |
ImportSourceCredentials | Grants permission to import the source repository credentials for an AWS CodeBuild project that has its source code stored in a GitHub, GitHub Enterprise, or Bitbucket repository | Write |  |  |
InvalidateProjectCache | Grants permission to reset the cache for a project | Write | project* |  |
ListBuildBatches | Grants permission to get a list of build batch IDs, with each build batch ID representing a single build batch | List |  |  |
ListBuildBatchesForProject | Grants permission to get a list of build batch IDs for the specified build project, with each build batch ID representing a single build batch | List | project* |  |
ListBuilds | Grants permission to get a list of build IDs, with each build ID representing a single build | List |  |  |
ListBuildsForProject | Grants permission to get a list of build IDs for the specified build project, with each build ID representing a single build | List | project* |  |
ListConnectedOAuthAccounts [permission only] | Grants permission to list connected third-party OAuth providers. Only used in the AWS CodeBuild console | List |  |  |
ListCuratedEnvironmentImages | Grants permission to get information about Docker images that are managed by AWS CodeBuild | List |  |  |
ListProjects | Grants permission to get a list of build project names, with each build project name representing a single build project | List |  |  |
ListReportGroups | Grants permission to return a list of report group ARNs. Each report group ARN represents one report group | List |  |  |
ListReports | Grants permission to return a list of report ARNs. Each report ARN representing one report | List |  |  |
ListReportsForReportGroup | Grants permission to return a list of report ARNs that belong to the specified report group. Each report ARN represents one report | List | report-group* |  |
ListRepositories [permission only] | Grants permission to list source code repositories from a connected third-party OAuth provider. Only used in the AWS CodeBuild console | List |  |  |
ListSharedProjects | Grants permission to return a list of project ARNs that have been shared with the requester. Each project ARN represents one project | List |  |  |
ListSharedReportGroups | Grants permission to return a list of report group ARNs that have been shared with the requester. Each report group ARN represents one report group | List |  |  |
ListSourceCredentials | Grants permission to return a list of SourceCredentialsInfo objects | List |  |  |
PersistOAuthToken [permission only] | Grants permission to save an OAuth token from a connected third-party OAuth provider. Only used in the AWS CodeBuild console | Write |  |  |
PutResourcePolicy | Grants permission to create a resource policy for the associated project or report group | Permissions management | project |  |
report-group |  |
RetryBuild | Grants permission to retry a build | Write | project* |  |
RetryBuildBatch | Grants permission to retry a build batch | Write | project* |  |
StartBuild | Grants permission to start running a build | Write | project* |  |
StartBuildBatch | Grants permission to start running a build batch | Write | project* |  |
StopBuild | Grants permission to attempt to stop running a build | Write | project* |  |
StopBuildBatch | Grants permission to attempt to stop running a build batch | Write | project* |  |
UpdateProject | Grants permission to change the settings of an existing build project | Write | project* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UpdateProjectVisibility | Grants permission to change the public visibility of a project and its builds | Write | project* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UpdateReport [permission only] | Grants permission to update information about a report | Write | report-group* |  |
UpdateReportGroup | Grants permission to change the settings of an existing report group | Write | report-group* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UpdateWebhook | Grants permission to update the webhook associated with an AWS CodeBuild build project | Write | project* |  |

## Resource types defined by AWS CodeBuild

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
build | `arn:$ { Partition}:codebuild:$ { Region}:$ { Account}:build/$ { BuildId}` |
build-batch | `arn:$ { Partition}:codebuild:$ { Region}:$ { Account}:build-batch/$ { BuildBatchId}` |
project | `arn:$ { Partition}:codebuild:$ { Region}:$ { Account}:project/$ { ProjectName}` | aws:ResourceTag/${TagKey}
report-group | `arn:$ { Partition}:codebuild:$ { Region}:$ { Account}:report-group/$ { ReportGroupName}` | aws:ResourceTag/${TagKey}
report | `arn:$ { Partition}:codebuild:$ { Region}:$ { Account}:report/$ { ReportGroupName}:$ { ReportId}` |

## Condition keys for AWS CodeBuild

AWS CodeBuild defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by actions based on the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access by actions based on tag key-value pairs attached to the resource | String
aws:TagKeys | Filters access by actions based on the presence of tag keys in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.